@@ -10,10 +10,10 @@ else:
 
 
 from django.contrib.admin.views.decorators import staff_member_required
-from .views import Shell
+from .views import ShellView
 
 app_name = 'django_admin_shell'
 
 urlpatterns = [
-    re_path(r'^$',  staff_member_required(Shell.as_view()), name="shell"),
+    re_path(r'^$', staff_member_required(ShellView.as_view()), name="shell"),
 ]
